@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.118_03';
+our $VERSION = '0.118_04';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Wed Mar 27 15:23:12 2019 GMT
+# on Sat Mar 30 15:23:36 2019 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1741,7 +1741,7 @@ __PACKAGE__->status( add => 25262, iridium => '-', 'Iridium 51', 'Tumbling' );
 __PACKAGE__->status( add => 25263, iridium => 'S', 'Iridium 61', '' );
 __PACKAGE__->status( add => 25272, iridium => '-', 'Iridium 55', 'Tumbling' );
 __PACKAGE__->status( add => 25273, iridium => '-', 'Iridium 57', 'Tumbling' );
-__PACKAGE__->status( add => 25274, iridium => 'S', 'Iridium 58', '' );
+__PACKAGE__->status( add => 25274, iridium => '-', 'Iridium 58', 'Tumbling' );
 __PACKAGE__->status( add => 25275, iridium => 'D', 'Iridium 59', 'Decayed 2019-03-11' );
 __PACKAGE__->status( add => 25276, iridium => 'D', 'Iridium 60', 'Decayed 2019-03-17' );
 __PACKAGE__->status( add => 25285, iridium => 'D', 'Iridium 62', 'Decayed 2018-11-07' );
@@ -1784,8 +1784,8 @@ __PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-0
 
 # Summary:
 # Operational [+]: 2
-#       Spare [S]: 3
-#    Tumbling [-]: 34
+#       Spare [S]: 2
+#    Tumbling [-]: 35
 #     Decayed [D]: 58
 
 1;
